#!/usr/bin/env ruby

require 'mapping'

# Represents a VirtualMachine, supports the following attributes
# * vm_id
# * name
# * deploy_id (ie. libvirt id)
# * cpu (mapped to VCPU)
# * memory (kbyte per ONE, byte per libvirt)
# * host_id and host_name (if the vm is deployed)
# * nics (the array of network interfaces, see: NicSI)
# * disks (the array of disks, see: DiskSI)
# * graphics (vnc information, see: GraphicsSI)
class VirtualMachineSI    
     include Mapping 
     def_public_attrs :vm_id, :name, :deploy_id, :cpu, :memory, :host_id, :host_name, :nics, :disks, :graphics
end

# Represents a VirtualMachine (see: VirtualMachineSI) disk, supports the following attributes
# * clone (is the source clone-able)
# * source (disk file location path or URL)
# * dev (device to map disk)
# * size
# * type (floppy, disk, cdrom, swap, fs, block)
# * format (filesystem type for the fs images)
# * save (should the disk be saved on vm delete)
class DiskSI
     include Mapping 
     def_public_attrs :clone, :source, :dev, :size, :type, :format, :save
end

# Represents a VirtualMachine (see: VirtualMachineSI) NIC, supports the following attributes
# * network (the name of the virtual network)
# * bridge (name of the bridge where the tap device is added to)
# * dev (name of the tap device)
# * ip
# * mac
class NicSI     
     include Mapping 
     def_public_attrs :network, :bridge, :dev, :ip, :mac
     def_public_attr :net_mac, false # false means: do not create default accessor methods
	 
     def net_mac
         if !mac.nil?
            iface_mac = mac.split(':')
            iface_mac[-1] = '00'
            @net_mac = iface_mac.join(':')
         end
         @net_mac
     end          
     
end

# Represents a VirtualMachine (see: VirtualMachineSI) graphics, supports the following attributes
# * type (we use only VNC but could be others as well)
# * ip (the IP address where VNC listens at the host, especially 0.0.0.0 for all IP-s)
# * port (the VNC TCP/IP port, not the monitor port)
# * password
# * keymap
class GraphicsSI
     include Mapping 
     def_public_attrs :type, :ip, :port, :password, :keymap      
end